.. pyranges documentation master file, created by
   sphinx-quickstart.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


The PyRanges documentation
==========================
PyRanges is a Python library specifically designed for efficient and intuitive manipulation of genomics data,
particularly genomic intervals (like genes, genomic features, or reads).
The library is optimized for fast querying and manipulation of genomic annotations.

Pyranges is open source, and hosted at github: https://github.com/pyranges/pyranges

Pyranges is developed by Endre Bakken Stovner and by
`Marco Mariotti's lab <https://www.mariottigenomicslab.com/>`_.




Citation
~~~~~~~~

Stovner EB, Sætrom P (2020) PyRanges: efficient comparison of genomic intervals in Python. *Bioinformatics 36(3):918-919*  http://dx.doi.org/10.1093/bioinformatics/btz615


Documentation outline
~~~~~~~~~~~~~~~~~~~~~

#. 🚀 :doc:`Installation instructions <./installation>`
#. 🚀 :doc:`The tutorial <./tutorial>`,  recommended for all new users
#. 🚀 :doc:`The how-to pages <./how_to_pages>`, further below, where functionalities are grouped by topic
#. 🚀 :doc:`The API reference <./api_reference>`, where all methods are explained in detail
#. 🚀 :doc:`The developer guide <./developer_guide>`, to follow in order to contribute to PyRanges



.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Contents:

   installation
   tutorial
   how_to_pages
   api_reference
   developer_guide


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
